﻿using System;
using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 비트맵 이미지
        /// </summary>
        private BitmapImage bitmapImage;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.bitmapImage = new BitmapImage();

            this.bitmapImage.BeginInit();

            this.bitmapImage.DecodePixelWidth = 300;
            this.bitmapImage.UriSource        = GetResourceURI(null, "IMAGE/sample.jpg");

            this.bitmapImage.EndInit();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 렌더링시 처리하기 - OnRender(drawingContext)

        /// <summary>
        /// 렌더링시 처리하기
        /// </summary>
        /// <param name="drawingContext">그리기 컨텍스트</param>
        protected override void OnRender(DrawingContext drawingContext)
        {
            if(this.bitmapImage != null)
            {
                drawingContext.DrawRectangle
                (
                    Brushes.White,
                    null,
                    new Rect
                    (
                        0,
                        0,
                        this.grid.ActualWidth,
                        this.grid.ActualHeight
                    )
                );

                Rect rectangle = new Rect
                (
                    (this.grid.ActualWidth  - this.bitmapImage.PixelWidth ) / 2,
                    (this.grid.ActualHeight - this.bitmapImage.PixelHeight) / 2,
                    this.bitmapImage.PixelWidth,
                    this.bitmapImage.PixelHeight
                );

                drawingContext.DrawImage(this.bitmapImage, rectangle);
            }
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 리소스 URI 구하기 - GetResourceURI(assemblyName, resourcePath)

        /// <summary>
        /// 리소스 URI 구하기
        /// </summary>
        /// <param name="assemblyName">어셈블리명</param>
        /// <param name="resourcePath">리소스 경로</param>
        /// <returns>리소스 URI</returns>
        private Uri GetResourceURI(string assemblyName, string resourcePath)
        {
            if(string.IsNullOrEmpty(assemblyName))
            {
                return new Uri(string.Format("pack://application:,,,/{0}", resourcePath));
            }
            else
            {
                return new Uri(string.Format("pack://application:,,,/{0};component/{1}", assemblyName, resourcePath));
            }
        }

        #endregion
    }
}